// Copyright 2020 Buf Technologies, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package buflint

import (
	"github.com/bufbuild/buf/internal/buf/bufcheck/internal"
)

type checker struct {
	*internal.Checker
}

func newChecker(internalChecker *internal.Checker) *checker {
	return &checker{Checker: internalChecker}
}

func (c *checker) internalLint() *internal.Checker {
	return c.Checker
}

func internalCheckersToCheckers(internalCheckers []*internal.Checker) []Checker {
	if internalCheckers == nil {
		return nil
	}
	checkers := make([]Checker, len(internalCheckers))
	for i, internalChecker := range internalCheckers {
		checkers[i] = newChecker(internalChecker)
	}
	return checkers
}

func checkersToInternalCheckers(checkers []Checker) []*internal.Checker {
	if checkers == nil {
		return nil
	}
	internalCheckers := make([]*internal.Checker, len(checkers))
	for i, checker := range checkers {
		internalCheckers[i] = checker.internalLint()
	}
	return internalCheckers
}
